@@ -68,12 +68,12 @@ def downloadImageSamples(folder='train'):
     os.remove(destination)
     
 def downloadFileInNeed(filename):
-'''
-downloadFileInNeed(filename)
-dowload file from dlib web site:
-http://dlib.net/files
-filename: for example ==>"shape_predictor_68_face_landmarks.dat"
-'''
+    '''
+    downloadFileInNeed(filename)
+    dowload file from dlib web site:
+    http://dlib.net/files
+    filename: for example ==>"shape_predictor_68_face_landmarks.dat"
+    '''
     if not os.path.isfile(filename):
         print("載入"+filename+"...可能需要一點時間") 
         url="http://dlib.net/files/"+filename+".bz2"
@@ -180,8 +180,8 @@ def predictFromDB(VTest,db=DB):
     '''
     minD = sys.float_info.max
     minK=''
-    for k in DB:
-        dist=numpy.linalg.norm(VTest-DB[k])
+    for k in db:
+        dist=numpy.linalg.norm(VTest-db[k])
         if dist<minD:
             minK=k
             minD=dist
@@ -282,7 +282,7 @@ def captureImageFromCamAndSave(tag,folder="train",camSerial=None):
     cv2.destroyAllWindows()
     return ret
 
-def predictCam(camSerial=None,skipFranmes=1,outputFileName=""):
+def predictCam(camSerial=None,skipFranmes=1,outputFileName="",db=DB):
     '''
         predictCam(camSerial=None,skipFranmes=1,outputFileName="")
         
@@ -312,7 +312,7 @@ def predictCam(camSerial=None,skipFranmes=1,outputFileName=""):
                 rects=_detector(frame, 1)
                 for rect in rects:
                     V=getFeatureVector(frame,rect)
-                    Tag,dist=predictFromDB(V) # predict the target Tag
+                    Tag,dist=predictFromDB(V,db) # predict the target Tag
                     cv2.rectangle(frame,(rect.left(),rect.top()),(rect.right(),rect.bottom()),(255,0,0),3)
                     #cv2.putText(frame, Tag+":"+str(dist),, cv2.FONT_HERSHEY_SIMPLEX,1, (255, 0, 0), 2, cv2.LINE_AA)
                     text=Tag+":"+str(dist)
@@ -346,7 +346,7 @@ def predictVedio(vedioPath,skipFranmes=10,db=DB):
             rects=_detector(frame, 1)
             for rect in rects:
                 V=getFeatureVector(frame,rect)
-                Tag,dist=predictFromDB(V,DB) # predict the target Tag
+                Tag,dist=predictFromDB(V,db) # predict the target Tag
                 cv2.rectangle(frame,(rect.left(),rect.top()),(rect.right(),rect.bottom()),(255,0,0),3)
                 text=Tag+":"+str(dist)
                 frame=addText2Img_cv2(frame,Tag+":"+str(round(dist,3)),_FONT,(rect.left(), rect.top()-_FONT.size-1))        
@@ -379,6 +379,5 @@ if __name__ == "__main__":
     loadDB(folder='train')
     predictCam()
     '''
-    loadDB(folder='train')
-    predictCam(camSerial=1,outputFileName="result.txt")
+    
     
\ No newline at end of file
